@@ -228,7 +228,7 @@ EOH
 
 		my $type = ($preconf -> {core_skip_boot} || $conf -> {core_skip_boot}) || $_REQUEST {__windows_ce} ? 'logon' : '_boot';
 		
-		redirect ("/?type=$type&redirect_params=" . b64u_freeze (\%_REQUEST));
+		redirect ("/?type=$type&redirect_params=" . b64u_freeze (\%_REQUEST), kind => 'js', target => '_top');
 		
 	}
 
@@ -422,7 +422,8 @@ EOH
 
 			if (
 				$conf -> {core_auto_esc} == 2 && 
-				$_REQUEST {sid} && 
+				$_REQUEST {sid} &&
+				!$_REQUEST {__top} &&
 				(
 					$r -> headers_in -> {'Referer'} =~ /action=\w/ ||
 					$r -> headers_in -> {'Referer'} !~ /__last_query_string=$_REQUEST{__last_query_string}/ ||
