@@ -492,7 +492,7 @@ sub draw__boot {
 			
 		}					
 						
-		nope ('$_REQUEST{__uri}?type=logon&redirect_params=$_REQUEST{redirect_params}', '_self');
+		nope ('$_REQUEST{__uri}?type=logon&redirect_params=$_REQUEST{redirect_params}', '_top');
 
 		setTimeout ("document.getElementById ('abuse_1').style.display = 'block'", 10000);
 		
@@ -1894,10 +1894,6 @@ sub draw_toolbar_input_select {
 		$value -> {selected} = (($value -> {id} eq $_REQUEST {$options -> {name}}) or ($value -> {id} eq $options -> {value})) ? 'selected' : '';
 	}
 
-
-
-
-
 	$options -> {onChange} = 'submit();';
 
 	$options -> {onChange} = '' if defined $options -> {other} || defined $options -> {detail};
@@ -1990,6 +1986,13 @@ sub draw_toolbar_input_text {
 
 	my ($options) = @_;
 	
+	$options -> {id} ||= ('' . $options);
+
+	$conf -> {kb_options_focus} ||= $conf -> {kb_options_buttons};
+	$conf -> {kb_options_focus} ||= {ctrl => 1, alt => 1};
+
+	register_hotkey ($options, 'focus_id', $options -> {id}, $conf -> {kb_options_focus});
+	
 	$options -> {value} ||= $_REQUEST {$options -> {name}};	
 	$options -> {size} ||= 15;		
 	$options -> {keep_params} ||= [keys %_REQUEST];
@@ -2370,6 +2373,7 @@ sub draw_menu {
 		$conf -> {kb_options_menu} ||= {ctrl => 1, alt => 1};
 
 		$type -> {name} ||= "$type->{items}";
+		$type -> {name} ||= "$type";
 
 		register_hotkey ($type, 'href', 'main_menu_' . $type -> {name}, $conf -> {kb_options_menu});
 		
